spl

Module oxidizer

This module creates a rust application that runs the desired SPL. At its current stage, this is just parsing and rewriting @rust functions from SPL into actual rust. The future plan is for this to effectively become a compiler.

Structs