pub struct RustAppBuilder { /* private fields */ }Expand description
A builder for RustApps. This is work-in-progress.
Implementations
Sourceimpl RustAppBuilder
impl RustAppBuilder
pub fn new() -> RustAppBuilder
Sourcepub fn add_source(&mut self, name: String, source: String)
pub fn add_source(&mut self, name: String, source: String)
Embeds a file into the desired app
Sourcepub fn prepare(&mut self, spl: Words) -> bool
pub fn prepare(&mut self, spl: Words) -> bool
Adds all @rust functions from the given SPL code’s top level. Does NOT scan for lower levels at this time.
Sourcepub fn set_default_file(&mut self, name: String)
pub fn set_default_file(&mut self, name: String)
Sets the default file to start when none is provided. This will not work if the file is not also embedded.