Structs
- Wrapper for ErrorKind with the stack trace.
- An SPL stack frame.
- A frame’s location in SPL code.
- Any kind of SPL-executable code with metadata surrounding it.
- Any kind of SPL object, no matter if it is a construct or not.
- An SPL runtime.
- An SPL stack.
- Any SPL type.
- A collection of executable words.
Enums
- Any error SPL can handle and throw.
- Any kind of SPL-executable code.
- An SPL keyword. Used to deviate from normal linear code structure.
- Any SPL value that is not a construct.
- The smallest fragment of SPL code.
Traits
- Trait for converting things to SPL Objects.
- Anything that can be .set() and result in the runtime being set. Implemented for Arc<Mut
> and Runtime.
Functions
- Finds a file in the SPL_PATH, or returns the internal stdlib version of it.
- Obtains a reference to the runtime.
- Obtains a mutable reference to the runtime.